@@ -1,8 +1,10 @@
 #include "TkInterp.h"
  
-int main (int argc, char *argv[])
+int
+main (int argc, const char **argv)
 {
   id tk = [[TkInterp alloc] initWithArgc:argc argv:argv];
+  
   [tk promptAndEval];
   exit(0);
 }
